
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
    <script>
import extend from "@/extension/outbound/mesPPOutboundOrder.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "PP仓大卷MES出库单",
      name: "mesPPOutboundOrder",
      url: "/mesPPOutboundOrder/",
      sortName: "id",
    });
    const editFormFields = ref({});
    const editFormOptions = ref([[]]);
    const searchFormFields = ref({
      orderNo: "",
      materialCode: "",
      batchNo: "",
    });
    const searchFormOptions = ref([
      [
        { title: "单据编号", field: "orderNo", type: "like" },
        { title: "物料编号", field: "materialCode", type: "like" },
        { title: "批次号", field: "batchNo", type: "like" },
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        align: "left",
      },
      {
        field: "warehouseId",
        title: "所属仓库",
        type: "string",
        width: 80,
        align: "left",
        bind: { key: "warehouses", data: [] },
      },
      {
        field: "orderNo",
        title: "单据编号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "taskNo",
        title: "任务单号",
        type: "string",
        width: 150,
        align: "left",
      },
      // {
      //   field: "batchNo",
      //   title: "批次号",
      //   type: "decimal",
      //   width: 90,
      //   align: "left",
      // },
      {
        field: "OrderStatus",
        title: "订单状态",
        type: "string",
        width: 180,
        align: "left",
        bind: { key: "orderDetailStatusEnum", data: [] },
      },
      {
        field: "materialCode",
        title: "物料编号",
        type: "string",
        width: 200,
        align: "left",
      },
      {
        field: "materialName",
        title: "物料名称",
        type: "string",
        width: 180,
        align: "left",
      },
      {
        field: "createType",
        title: "创建方式",
        type: "string",
        width: 120,
        align: "left",
        bind: { key: "createType", data: [] },
      },
      {
        field: "unit",
        title: "单位",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "orderQuantity",
        title: "单据数量",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "lockQuantity",
        title: "锁定数量",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "overOutQuantity",
        title: "已出数量",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "line",
        title: "线体",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "targetAddressCode",
        title: "线边仓地址码",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "width",
        title: "裁切宽",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "出库明细单",
      table: "OnboundOrderDetail",
      columns: [
        {
          field: "id",
          title: "Id",
          type: "int",
          width: 90,
          hidden: true,
          readonly: true,
          require: true,
          align: "left",
        },
        {
          field: "orderId",
          title: "出库单主键",
          type: "string",
          width: 90,
          align: "left",
          hidden: true,
        },
        {
          field: "Warehouse",
          title: "库区",
          type: "string",
          width: 150,
          align: "left",
        },
        {
          field: "CarrierCode",
          title: "载具号",
          type: "string",
          width: 150,
          align: "left",
        },
        {
          field: "orderDetailStatus",
          title: "订单明细状态",
          type: "string",
          width: 180,
          align: "left",
          bind: { key: "orderDetailStatusEnum", data: [] },
        },
        {
          field: "creater",
          title: "创建人",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "createDate",
          title: "创建时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
        {
          field: "modifier",
          title: "修改人",
          type: "string",
          width: 100,
          align: "left",
        },
        {
          field: "modifyDate",
          title: "修改时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
        {
          field: "remark",
          title: "备注",
          type: "string",
          width: 100,
          align: "left",
        },
      ],
      sortName: "id",
      key: "id",
    });

    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
    